=== modified file 'CHANGELOG.md'
--- CHANGELOG.md	2016-09-10 14:58:32 +0000
+++ CHANGELOG.md	2016-09-13 14:57:54 +0000
@@ -10,8 +10,8 @@
 
 ##### COMPATIBLE CHANGES
 
-- Remove incompatibilities to support nested tuplets
-- MusicXML importer now supports tuplets
+- MusicXML importer now supports tuplets.
+- Nested tuplets now fully supported in LDP and rendered in Lomse.
 - Fixed spacing issues, related to clefs and prolog objects, detected 
   in regression tests.
 - Blank space in LDP exporter has been normalized.

=== modified file 'include/lomse_engraving_options.h'
--- include/lomse_engraving_options.h	2016-08-29 11:01:43 +0000
+++ include/lomse_engraving_options.h	2016-09-13 14:57:54 +0000
@@ -92,7 +92,8 @@
 #define LOMSE_TUPLET_BRACKET_DISTANCE   10.0f
 #define LOMSE_TUPLET_NUMBER_DISTANCE     5.0f
 #define LOMSE_TUPLET_BRACKET_THICKNESS   2.0f
-#define LOMSE_TUPLET_SPACE_TO_NUMBER     3.0f
+#define LOMSE_TUPLET_SPACE_TO_NUMBER     3.0f
+#define LOMSE_TUPLET_NESTED_DISTANCE    20.0f
 
 //ties
 #define LOMSE_TIE_VERTICAL_SPACE         3.0f   //vertical distance from notehead

=== modified file 'include/lomse_ldp_analyser.h'
--- include/lomse_ldp_analyser.h	2016-09-10 14:58:32 +0000
+++ include/lomse_ldp_analyser.h	2016-09-13 14:57:54 +0000
@@ -172,6 +172,8 @@
 
     inline ImoTuplet* get_last_created_tuplet() { return m_pTuplet; }
 
+    void add_to_open_tuplets(ImoNoteRest* pNR);
+
 };
 
 
@@ -281,6 +283,9 @@
     inline ImoTuplet* get_last_created_tuplet() {
          return m_pTupletsBuilder->get_last_created_tuplet();
     }
+    inline void add_to_open_tuplets(ImoNoteRest* pNR) {
+        m_pTupletsBuilder->add_to_open_tuplets(pNR);
+    }
 
     //interface for building lyric lines
     void add_lyric(ImoNote* pNote, ImoLyric* pL);

=== modified file 'include/lomse_mxl_analyser.h'
--- include/lomse_mxl_analyser.h	2016-09-09 13:44:56 +0000
+++ include/lomse_mxl_analyser.h	2016-09-13 14:57:54 +0000
@@ -109,6 +109,7 @@
 
     void add_relation_to_notes_rests(ImoTupletDto* pEndInfo);
     inline bool is_tuplet_open() { return m_pendingItems.size() > 0; }
+    void add_to_open_tuplets(ImoNoteRest* pNR);
 };
 
 //---------------------------------------------------------------------------------------
@@ -322,6 +323,9 @@
 
     //interface for MxlTupletsBuilder
     inline bool is_tuplet_open() { return m_pTupletsBuilder->is_tuplet_open(); }
+    inline void add_to_open_tuplets(ImoNoteRest* pNR) {
+        m_pTupletsBuilder->add_to_open_tuplets(pNR);
+    }
 
 //    //interface for ChordBuilder
 //    void add_chord(ImoChord* pChord);

=== modified file 'include/lomse_tuplet_engraver.h'
--- include/lomse_tuplet_engraver.h	2016-07-23 14:26:45 +0000
+++ include/lomse_tuplet_engraver.h	2016-09-13 14:57:54 +0000
@@ -65,6 +65,7 @@
     ShapeBoxInfo m_shapesInfo[1];
     bool m_fDrawBracket;
     bool m_fDrawNumber;
+    bool m_fAbove;
 
 public:
     TupletEngraver(LibraryScope& libraryScope, ScoreMeter* pScoreMeter);
@@ -107,10 +108,11 @@
     LUnits m_yStart, m_yEnd;
 
     void decide_if_show_bracket();
-    bool decide_if_tuplet_placement_above();
+    void decide_tuplet_placement();
     void determine_tuplet_text();
     void create_shape();
     void set_shape_details();
+    int count_nested_tuplets();
 
 };
 

=== modified file 'src/document/lomse_document.cpp'
--- src/document/lomse_document.cpp	2016-09-10 14:58:32 +0000
+++ src/document/lomse_document.cpp	2016-09-13 14:57:54 +0000
@@ -48,6 +48,7 @@
 #include "lomse_ldp_elements.h"
 #include "lomse_control.h"
 #include "lomse_logger.h"
+#include "lomse_staffobjs_table.h"
 
 #include <sstream>
 using namespace std;
@@ -456,11 +457,31 @@
                 a.add_relation_info(pTupletStart);
                 pStartNR->set_dirty(true);
 
+                //add the tuplet to intermediate notes
+                int numTuplet = pTupletStart->get_item_number();
+                ColStaffObjs* pCol = pStartNR->get_score()->get_staffobjs_table();
+                ColStaffObjsIterator it = pCol->find(pStartNR);
+                int line = (*it)->line();
+                ++it;   //skip start note
+                while ((*it)->imo_object() != pEndNR)
+                {
+                    if ((*it)->imo_object()->is_note_rest() && (*it)->line() == line)
+                    {
+                        ImoNoteRest* pNR = static_cast<ImoNoteRest*>((*it)->imo_object());
+                        ImoTupletDto* pInfo = LOMSE_NEW ImoTupletDto();
+                        pInfo->set_tuplet_type(ImoTupletDto::k_continue);
+                        pInfo->set_note_rest(pNR);
+                        pInfo->set_tuplet_number(numTuplet);
+                        a.add_relation_info(pInfo);
+                    }
+                    ++it;
+                }
+
                 //create end of tuplet and attach it to end note/rest
                 ImoTupletDto* pTupletEnd = LOMSE_NEW ImoTupletDto();
                 pTupletEnd->set_tuplet_type(ImoTupletDto::k_stop);
                 pTupletEnd->set_note_rest(pEndNR);
-                pTupletEnd->set_tuplet_number( pTupletStart->get_item_number() );
+                pTupletEnd->set_tuplet_number(numTuplet);
                 a.add_relation_info(pTupletEnd);
 
                 //get the tuplet

=== modified file 'src/exporters/lomse_ldp_exporter.cpp'
--- src/exporters/lomse_ldp_exporter.cpp	2016-09-10 17:56:38 +0000
+++ src/exporters/lomse_ldp_exporter.cpp	2016-09-13 14:57:54 +0000
@@ -2619,7 +2619,7 @@
 
         if (m_pNR == m_pTuplet->get_start_object())
         {
-            start_element("t", m_pTuplet->get_id());
+            start_element("t", m_pTuplet->get_id(), k_in_same_line);
             add_tuplet_number();
             add_tuplet_type(true);
             add_actual_notes();

=== modified file 'src/graphic_model/engravers/lomse_tuplet_engraver.cpp'
--- src/graphic_model/engravers/lomse_tuplet_engraver.cpp	2016-07-23 14:26:45 +0000
+++ src/graphic_model/engravers/lomse_tuplet_engraver.cpp	2016-09-13 14:57:54 +0000
@@ -105,6 +105,7 @@
 int TupletEngraver::create_shapes(Color color)
 {
     m_color = color;
+    decide_tuplet_placement();
     decide_if_show_bracket();
     determine_tuplet_text();
 
@@ -143,9 +144,7 @@
     LUnits uNumberDistance = tenths_to_logical(LOMSE_TUPLET_NUMBER_DISTANCE);
     LUnits uSpaceToNumber = tenths_to_logical(LOMSE_TUPLET_SPACE_TO_NUMBER);
 
-    bool fAbove = decide_if_tuplet_placement_above();
-
-    m_pTupletShape->set_layout_data(fAbove, m_fDrawBracket, m_yStart, m_yEnd,
+    m_pTupletShape->set_layout_data(m_fAbove, m_fDrawBracket, m_yStart, m_yEnd,
                                     uBorderLength, uBracketDistance,
                                     uLineThick, uNumberDistance, uSpaceToNumber,
                                     get_start_noterest_shape(),
@@ -176,13 +175,13 @@
 
 
 //---------------------------------------------------------------------------------------
-bool TupletEngraver::decide_if_tuplet_placement_above()
+void TupletEngraver::decide_tuplet_placement()
 {
     GmoShapeNote* pStart = get_first_note();
     bool fNotesUp = (pStart ? pStart->is_up() : true);
     int placement = m_pTuplet->get_placement();
-	return placement == k_placement_above
-           || (placement == k_placement_default && fNotesUp);
+	m_fAbove = placement == k_placement_above
+               || (placement == k_placement_default && fNotesUp);
 }
 
 //---------------------------------------------------------------------------------------
@@ -199,30 +198,97 @@
     GmoShapeNote* pStart = get_first_note();
     GmoShapeNote* pEnd = get_last_note();
 
-    //determine y start/end coordinates
-    GmoShapeBeam* pBeamShape = dynamic_cast<GmoShapeBeam*>(
+    GmoShapeBeam* pBeamShapeStart = dynamic_cast<GmoShapeBeam*>(
                                     pStart->find_related_shape(GmoObj::k_shape_beam) );
-    if (pBeamShape)
-    {
-        //case a): tuplet encloses a whole beamed group
-        UPoint pos = pBeamShape->get_outer_left_reference_point();
-        m_yStart = pos.y;
-        pos = pBeamShape->get_outer_right_reference_point();
-        m_yEnd = pos.y;
-    }
+    GmoShapeBeam* pBeamShapeEnd = dynamic_cast<GmoShapeBeam*>(
+                                    pEnd->find_related_shape(GmoObj::k_shape_beam) );
+
+    if (pBeamShapeStart && pBeamShapeStart == pBeamShapeEnd)
+    {
+        //tuplet encloses a whole beamed group. Use the beam as reference
+        UPoint pos = pBeamShapeStart->get_outer_left_reference_point();
+        m_yStart = pos.y;
+        pos = pBeamShapeStart->get_outer_right_reference_point();
+        m_yEnd = pos.y;
+    }
+
+    else if (pBeamShapeStart && pBeamShapeEnd)
+    {
+        //start and end in beam but different, try to follow beams slant
+        UPoint pos = pBeamShapeStart->get_outer_left_reference_point();
+        m_yStart = pos.y;
+        pos = pBeamShapeStart->get_outer_right_reference_point();
+        m_yEnd = pos.y;
+    }
+
     else
     {
-        //case b): tuplet encloses a whole group but not beamed
-        //case c): tuplet encloses several beamed groups and notes/rests
-        if (pStart->is_up())
-        {
-            m_yStart = pStart->get_top();
-            m_yEnd = pEnd->get_top();
-        }
-        else
-        {
-            m_yStart = pStart->get_bottom();
-            m_yEnd = pEnd->get_bottom();
+        //otherwise, draw an horizontal tuplet
+        LUnits yMax = m_yStart = pStart->get_top();
+        LUnits yMin = yMax;
+
+        std::list< pair<ImoNoteRest*, GmoShape*> >::iterator it;
+        for (it = m_noteRests.begin(); it != m_noteRests.end(); ++it)
+        {
+            ImoNoteRest* pNR = static_cast<ImoNoteRest*>((*it).first);
+            if (pNR->is_note())
+            {
+                ImoNote* pNote = static_cast<ImoNote*>(pNR);
+                GmoShapeNote* pNoteShape = static_cast<GmoShapeNote*>((*it).second);
+                if (pNote->is_beamed())
+                {
+                    if (pNote->is_end_of_beam())
+                    {
+                        GmoShapeBeam* pBeamShape = dynamic_cast<GmoShapeBeam*>(
+                                          pNoteShape->find_related_shape(GmoObj::k_shape_beam) );
+                        UPoint pos = pBeamShape->get_outer_right_reference_point();
+                        yMax = max(yMax, pos.y);
+                        yMin = min(yMin, pos.y);
+                        pos = pBeamShape->get_outer_left_reference_point();
+                        yMax = max(yMax, pos.y);
+                        yMin = min(yMin, pos.y);
+                    }
+                }
+                else
+                {
+                    //not beamed note
+                    if (m_fAbove)
+                    {
+                        yMax = max(yMax, pNoteShape->get_top());
+                        yMin = min(yMin, pNoteShape->get_top());
+                    }
+                    else
+                    {
+                        yMax = max(yMax, pNoteShape->get_bottom());
+                        yMin = min(yMin, pNoteShape->get_bottom());
+                    }
+                }
+            }
+        }
+
+        //set position for horizontal bracket
+        if (m_fAbove)
+            m_yStart = yMin;
+        else
+            m_yStart = yMax;
+
+        m_yEnd = m_yStart;
+    }
+
+    //add space for nested
+    int nested = count_nested_tuplets();
+    if (nested > 0)
+    {
+        LUnits shift = nested * tenths_to_logical(LOMSE_TUPLET_NESTED_DISTANCE);
+        if (m_fAbove)
+        {
+            m_yStart -= shift;
+            m_yEnd -= shift;
+        }
+        else
+        {
+            m_yStart += shift;
+            m_yEnd += shift;
         }
     }
 }
@@ -264,5 +330,35 @@
     return false;
 }
 
+//---------------------------------------------------------------------------------------
+int TupletEngraver::count_nested_tuplets()
+{
+    int maxTuplets = 0;
+    int openTuplets = 0;
+    std::list< pair<ImoNoteRest*, GmoShape*> >::iterator it;
+    for (it = m_noteRests.begin(); it != m_noteRests.end(); ++it)
+    {
+        ImoNoteRest* pNR = static_cast<ImoNoteRest*>((*it).first);
+        if (pNR->get_num_relations() > 0)
+        {
+            ImoRelations* pRelObjs = pNR->get_relations();
+            int size = pRelObjs->get_num_items();
+            for (int i=0; i < size; ++i)
+            {
+                ImoRelObj* pRO = pRelObjs->get_item(i);
+                if (pRO->is_tuplet())
+                {
+                    if (pRO->get_start_object() == pNR)
+                        openTuplets++;
+                    else if (pRO->get_end_object() == pNR)
+                        openTuplets--;
+                }
+            }
+        }
+        maxTuplets = max(maxTuplets, openTuplets);
+    }
+    return --maxTuplets;
+}
+
 
 }  //namespace lomse

=== modified file 'src/graphic_model/lomse_shape_tuplet.cpp'
--- src/graphic_model/lomse_shape_tuplet.cpp	2016-06-26 14:49:20 +0000
+++ src/graphic_model/lomse_shape_tuplet.cpp	2016-09-13 14:57:54 +0000
@@ -110,7 +110,9 @@
     if (m_pShapeText)
     {
         m_uNumberWidth = m_pShapeText->get_width();
-        uNumberHeight = m_pShapeText->get_height();
+        uNumberHeight = 1.33f * m_pShapeText->get_height();
+            //1.33 accounts for the fact that there is some space on top of the
+            //number glyph
     }
 
     //determine number x position
@@ -122,7 +124,7 @@
     yShift += (m_fAbove ? -uNumberHeight : 0.0f);
     m_yNumber += yShift;
 
-    //move nomber shape to its position
+    //move number shape to its position
     if (m_pShapeText)
         m_pShapeText->set_origin(m_xNumber, m_yNumber);
 

=== modified file 'src/parser/ldp/lomse_ldp_analyser.cpp'
--- src/parser/ldp/lomse_ldp_analyser.cpp	2016-09-10 14:58:32 +0000
+++ src/parser/ldp/lomse_ldp_analyser.cpp	2016-09-13 14:57:54 +0000
@@ -3925,13 +3925,8 @@
         //tuplet
         if (fAddOldTuplet)
             set_old_tuplet(pNR);
-        else if (m_pTupletInfo==NULL
-                 && m_pAnalyser->is_tuplet_open()
-                 && m_pAnalyser->get_score_version() <= 107
-                )
-            add_to_current_tuplet(pNR);
-
-        add_tuplet_info(pNR);
+        else
+            add_tuplet_info(pNR);
 
         //time modification
         if (m_pTimeModifDto != NULL)
@@ -3969,22 +3964,6 @@
       //  }
 
             ImoTreeAlgoritms::add_note_to_chord(pStartOfChordNote, pNote, pDoc);
-
-//            ImoChord* pChord;
-//            if (pStartOfChordNote->is_in_chord())
-//            {
-//                //chord already created. just add note to it
-//                pChord = pStartOfChordNote->get_chord();
-//            }
-//            else
-//            {
-//                //previous note is the base note. Create the chord
-//                pChord = static_cast<ImoChord*>(ImFactory::inject(k_imo_chord, pDoc));
-//                pStartOfChordNote->include_in_relation(pDoc, pChord);
-//            }
-//
-//            //add current note to chord
-//            pNote->include_in_relation(pDoc, pChord);
         }
 
         //save this note as last note
@@ -4159,14 +4138,6 @@
         }
     }
 
-    void add_to_current_tuplet(ImoNoteRest* pNR)
-    {
-        ImoTupletDto* pInfo = LOMSE_NEW ImoTupletDto();
-        pInfo->set_note_rest(pNR);
-        pInfo->set_tuplet_type(ImoTupletDto::k_continue);
-        m_pAnalyser->add_relation_info(pInfo);
-    }
-
     void set_old_tuplet(ImoNoteRest* pNR)
     {
         string value = m_srcOldTuplet;
@@ -4212,7 +4183,6 @@
             {
                 report_msg(m_pParamToAnalyse->get_line_number(),
                     "Requesting to start a tuplet but there is already an open tuplet. Tuplet ignored.");
-                add_to_current_tuplet(pNR);
             }
             else
             {
@@ -4249,6 +4219,7 @@
             //    pInfo->set_normal_number(0);  //required
         }
         ImoTupletDto* pInfo = LOMSE_NEW ImoTupletDto();
+        pInfo->set_tuplet_type(ImoTupletDto::k_start);
         pInfo->set_note_rest(pNR);
         pInfo->set_actual_number(actual);
         pInfo->set_normal_number(normal);
@@ -4285,9 +4256,17 @@
     {
         if (m_pTupletInfo)
         {
+            if (m_pTupletInfo->is_start_of_tuplet())
+                m_pAnalyser->add_to_open_tuplets(pNR);
+
             m_pTupletInfo->set_note_rest(pNR);
             m_pAnalyser->add_relation_info(m_pTupletInfo);
+
+            if (m_pTupletInfo->is_end_of_tuplet())
+                m_pAnalyser->add_to_open_tuplets(pNR);
         }
+        else
+            m_pAnalyser->add_to_open_tuplets(pNR);
     }
 
     void add_beam_info(ImoNoteRest* pNR)
@@ -6078,8 +6057,23 @@
         set_default_values(pInfo);
 
         // [<tupletID>]     //optional. Only required for nested tuplets
-        if (get_optional(k_number))
-            set_tuplet_id(pInfo);
+        // <tupletID>   Mandatory since 2.1, for nested tuplets
+        // if (m_pAnalyser->get_score_version() > 200)
+        //{
+        //    if (get_mandatory(k_number))
+        //        set_tuplet_id(pInfo);
+        //    else
+        //    {
+        //        error_msg("Missing or invalid tuplet number. Tuplet ignored.");
+        //        delete pInfo;
+        //        return;
+        //    }
+        //}
+        //else
+        {
+            if (get_optional(k_number))
+                set_tuplet_id(pInfo);
+        }
 
         // { + | - }
         if (!get_mandatory(k_label) || !set_tuplet_type(pInfo))
@@ -7467,24 +7461,39 @@
     ImoTupletDto* pStartDto = m_matches.front();
     m_pTuplet = ImFactory::inject_tuplet(pDoc, pStartDto);
 
-    //if not only graphical (LDP < 2.0) add time modification to all note/rest
-    if (!pStartDto->is_only_graphical())
+    //loop for including the tuplet in all note/rest
+    std::list<ImoTupletDto*>::iterator it;
+    for (it = m_matches.begin(); it != m_matches.end(); ++it)
     {
-        std::list<ImoTupletDto*>::iterator it;
-        for (it = m_matches.begin(); it != m_matches.end(); ++it)
-        {
-            ImoNoteRest* pNR = (*it)->get_note_rest();
+        //add tuplet to the note/rest
+        ImoNoteRest* pNR = (*it)->get_note_rest();
+        pNR->include_in_relation(pDoc, m_pTuplet, NULL);
+
+        //if not only graphical (LDP < 2.0) add time modification the note/rest
+        if (!pStartDto->is_only_graphical())
             pNR->set_time_modification( m_pTuplet->get_normal_number(),
                                         m_pTuplet->get_actual_number() );
-        }
-    }
-
-    //create tuplet data and add tuplet to start and end note/rest
-    ImoNoteRest* pNR = pStartDto->get_note_rest();
-    pNR->include_in_relation(pDoc, m_pTuplet, NULL);
-
-    pNR = pEndDto->get_note_rest();
-    pNR->include_in_relation(pDoc, m_pTuplet, NULL);
+    }
+}
+
+//---------------------------------------------------------------------------------------
+void TupletsBuilder::add_to_open_tuplets(ImoNoteRest* pNR)
+{
+    if (m_pendingItems.size() > 0)
+    {
+        ListIterator it;
+        for(it=m_pendingItems.begin(); it != m_pendingItems.end(); ++it)
+        {
+            if ((*it)->is_start_of_relation() )
+            {
+                ImoTupletDto* pInfo = LOMSE_NEW ImoTupletDto();
+                pInfo->set_tuplet_number( (*it)->get_item_number() );
+                pInfo->set_tuplet_type(ImoTupletDto::k_continue);
+                pInfo->set_note_rest(pNR);
+                save_item_info(pInfo);
+            }
+        }
+    }
 }
 
 

=== modified file 'src/parser/mxl/lomse_mxl_analyser.cpp'
--- src/parser/mxl/lomse_mxl_analyser.cpp	2016-09-10 14:58:32 +0000
+++ src/parser/mxl/lomse_mxl_analyser.cpp	2016-09-13 14:57:54 +0000
@@ -2897,6 +2897,9 @@
         {
         }
 
+        //add note/rest to open tuplets
+        m_pAnalyser->add_to_open_tuplets(pNR);
+
         // [<staff>]
         if (get_optional("staff"))
             set_staff(pNR);
@@ -4906,8 +4909,10 @@
 
         if (m_pInfo->is_start_of_tuplet())
         {
-            m_pInfo->set_actual_number( pNR->get_time_modifier_bottom() );
-            m_pInfo->set_normal_number( pNR->get_time_modifier_top() );
+            int top, bottom;
+            get_factors_for_nested_tuplets(pNR, &top, &bottom);
+            m_pInfo->set_actual_number( pNR->get_time_modifier_bottom() / bottom );
+            m_pInfo->set_normal_number( pNR->get_time_modifier_top() / top );
         }
 
         m_pInfo->set_note_rest(pNR);
@@ -5002,6 +5007,30 @@
 
     }
 
+    void get_factors_for_nested_tuplets(ImoNoteRest* pNR, int* pTop, int* pBottom)
+    {
+        *pTop = 1;
+        *pBottom = 1;
+        if (pNR->get_num_relations() > 0)
+        {
+            ImoRelations* pRelObjs = pNR->get_relations();
+            int size = pRelObjs->get_num_items();
+            for (int i=0; i < size; ++i)
+            {
+                ImoRelObj* pRO = pRelObjs->get_item(i);
+                if (pRO->is_tuplet())
+                {
+                    if (pRO->get_start_object() == pNR)
+                    {
+                        ImoTuplet* pTuplet = static_cast<ImoTuplet*>(pRO);
+                        *pTop *= pTuplet->get_normal_number();
+                        *pBottom *= pTuplet->get_actual_number();
+                    }
+                }
+            }
+        }
+    }
+
 };
 
 
@@ -5812,9 +5841,8 @@
 //=======================================================================================
 // MxlTupletsBuilder implementation
 //=======================================================================================
-void MxlTupletsBuilder::add_relation_to_notes_rests(ImoTupletDto* pEndDto)
+void MxlTupletsBuilder::add_relation_to_notes_rests(ImoTupletDto* UNUSED(pEndDto))
 {
-    m_matches.push_back(pEndDto);
     Document* pDoc = m_pAnalyser->get_document_being_analysed();
 
     ImoTupletDto* pStartDto = m_matches.front();
@@ -5828,6 +5856,26 @@
     }
 }
 
+//---------------------------------------------------------------------------------------
+void MxlTupletsBuilder::add_to_open_tuplets(ImoNoteRest* pNR)
+{
+    if (m_pendingItems.size() > 0)
+    {
+        ListIterator it;
+        for(it=m_pendingItems.begin(); it != m_pendingItems.end(); ++it)
+        {
+            if ((*it)->is_start_of_relation() )
+            {
+                ImoTupletDto* pInfo = LOMSE_NEW ImoTupletDto();
+                pInfo->set_tuplet_number( (*it)->get_item_number() );
+                pInfo->set_tuplet_type(ImoTupletDto::k_continue);
+                pInfo->set_note_rest(pNR);
+                save_item_info(pInfo);
+            }
+        }
+    }
+}
+
 //=======================================================================================
 //// MxlAutoBeamer implementation
 ////=======================================================================================

=== modified file 'src/tests/lomse_test_ldp_analyser.cpp'
--- src/tests/lomse_test_ldp_analyser.cpp	2016-09-10 14:58:32 +0000
+++ src/tests/lomse_test_ldp_analyser.cpp	2016-09-13 14:57:54 +0000
@@ -6691,8 +6691,7 @@
         CHECK( pNote != NULL);
         ImoTuplet* pTuplet = static_cast<ImoTuplet*>(pNote->find_relation(k_imo_tuplet));
         CHECK( pTuplet->is_tuplet() == true );
-        CHECK( pTuplet->get_num_objects() == 2 );
-//        cout << "num.objects = " << pTuplet->get_num_objects() << endl;
+        CHECK( pTuplet->get_num_objects() == 3 );
         CHECK( pTuplet->get_actual_number() == 3 );
         CHECK( pTuplet->get_normal_number() == 2 );
 
@@ -6701,6 +6700,8 @@
         std::list< pair<ImoStaffObj*, ImoRelDataObj*> >::iterator itN = notes.begin();
         ImoNote* pNt1 = dynamic_cast<ImoNote*>( (*itN).first );
         ++itN;
+        ImoNote* pNt2 = dynamic_cast<ImoNote*>( (*itN).first );
+        ++itN;
         ImoNote* pNt3 = dynamic_cast<ImoNote*>( (*itN).first );
 
 
@@ -6714,7 +6715,8 @@
         ++it;
         ImoNote* pNote2 = dynamic_cast<ImoNote*>( *it );
         CHECK( pNote2 != NULL );
-        CHECK( pNote2->find_relation(k_imo_tuplet) == NULL );
+        CHECK( pNote2 == pNt2 );
+        CHECK( pNote2->find_relation(k_imo_tuplet) == pTuplet );
 
         ++it;
         ImoNote* pNote3 = dynamic_cast<ImoNote*>( *it );
@@ -6873,7 +6875,7 @@
         ImoNote* pNote = dynamic_cast<ImoNote*>( *it );
         CHECK( pNote != NULL);
         ImoTuplet* pTuplet = static_cast<ImoTuplet*>(pNote->find_relation(k_imo_tuplet));
-        CHECK( pTuplet->get_num_objects() == 2 );
+        CHECK( pTuplet->get_num_objects() == 3 );
         CHECK( pTuplet->get_actual_number() == 3 );
         CHECK( pTuplet->get_normal_number() == 2 );
 
@@ -6882,6 +6884,8 @@
         std::list< pair<ImoStaffObj*, ImoRelDataObj*> >::iterator itN = notes.begin();
         ImoNote* pNt1 = dynamic_cast<ImoNote*>( (*itN).first );
         ++itN;
+        ImoNote* pNt2 = dynamic_cast<ImoNote*>( (*itN).first );
+        ++itN;
         ImoNote* pNt3 = dynamic_cast<ImoNote*>( (*itN).first );
 
         ImoNote* pNote1 = dynamic_cast<ImoNote*>( *it );
@@ -6891,6 +6895,7 @@
         ++it;
         ImoNote* pNote2 = dynamic_cast<ImoNote*>( *it );
         CHECK( pNote2 != NULL );
+        CHECK( pNote2 == pNt2 );
 
         ++it;
         ImoNote* pNote3 = dynamic_cast<ImoNote*>( *it );
@@ -7069,13 +7074,15 @@
         ImoRest* pRest = dynamic_cast<ImoRest*>( *it );
         CHECK( pRest != NULL);
         ImoTuplet* pTuplet = static_cast<ImoTuplet*>(pRest->find_relation(k_imo_tuplet));
-        CHECK( pTuplet->get_num_objects() == 2 );
+        CHECK( pTuplet->get_num_objects() == 3 );
 
         std::list< pair<ImoStaffObj*, ImoRelDataObj*> >& notes =
             pTuplet->get_related_objects();
         std::list< pair<ImoStaffObj*, ImoRelDataObj*> >::iterator itN = notes.begin();
         ImoRest* pNR1 = dynamic_cast<ImoRest*>( (*itN).first );
         ++itN;
+        ImoRest* pNR2 = dynamic_cast<ImoRest*>( (*itN).first );
+        ++itN;
         ImoRest* pNR3 = dynamic_cast<ImoRest*>( (*itN).first );
 
         CHECK( (*it)->is_rest() == true );
@@ -7088,6 +7095,7 @@
         ++it;
         ImoRest* pRest2 = dynamic_cast<ImoRest*>( *it );
         CHECK( pRest2 != NULL );
+        CHECK( pRest2 == pNR2 );
         CHECK( pRest2->get_voice() == 3 );
         CHECK( pRest2->get_staff() == 1 );
         CHECK( pRest2->has_attachments() == true );

=== modified file 'src/tests/lomse_test_ldp_exporter.cpp'
--- src/tests/lomse_test_ldp_exporter.cpp	2016-09-10 17:56:38 +0000
+++ src/tests/lomse_test_ldp_exporter.cpp	2016-09-13 14:57:54 +0000
@@ -1309,10 +1309,10 @@
         //cout << test_name() << endl << "\"" << source << "\"" << endl;
         string expected =
             "(musicData (clef G p1)"
-            "(n c4 e v1 p1 (tm 3 2)(beam 110 +)(t 107 + 2 3))"
-            "(n d4 s v1 p1 (tm 3 2)(beam 110 =+))"
-            "(n c4 s v1 p1 (tm 3 2)(beam 110 ==))"
-            "(n b3 e v1 p1 (tm 3 2)(beam 110 --)(t 107 -))"
+            "(n c4 e v1 p1 (tm 3 2)(beam 112 +)(t 107 + 2 3))"
+            "(n d4 s v1 p1 (tm 3 2)(beam 112 =+))"
+            "(n c4 s v1 p1 (tm 3 2)(beam 112 ==))"
+            "(n b3 e v1 p1 (tm 3 2)(beam 112 --)(t 107 -))"
             ")";
         CHECK( source == expected );
     }
@@ -1339,10 +1339,10 @@
         //cout << test_name() << endl << "\"" << source << "\"" << endl;
         string expected =
             "(musicData (clef G p1)"
-            "(n c4 e v1 p1 (tm 3 2)(beam 110 +)(t 107 + 2 3))"
-            "(n d4 s v1 p1 (tm 3 2)(beam 110 =+))"
-            "(n c4 s v1 p1 (tm 3 2)(beam 110 ==))"
-            "(n b3 e v1 p1 (tm 3 2)(beam 110 --)(t 107 -))"
+            "(n c4 e v1 p1 (tm 3 2)(beam 112 +)(t 107 + 2 3))"
+            "(n d4 s v1 p1 (tm 3 2)(beam 112 =+))"
+            "(n c4 s v1 p1 (tm 3 2)(beam 112 ==))"
+            "(n b3 e v1 p1 (tm 3 2)(beam 112 --)(t 107 -))"
             ")";
         CHECK( source == expected );
     }

=== modified file 'src/tests/lomse_test_mxl_analyser.cpp'
--- src/tests/lomse_test_mxl_analyser.cpp	2016-09-10 14:58:32 +0000
+++ src/tests/lomse_test_mxl_analyser.cpp	2016-09-13 14:57:54 +0000
@@ -2069,7 +2069,7 @@
         CHECK( pTuplet->get_actual_number() == 1 );
         CHECK( pTuplet->get_normal_number() == 1 );
         CHECK( pTuplet->get_show_bracket() == k_yesno_default );
-        CHECK( pTuplet->get_num_objects() == 2 );
+        CHECK( pTuplet->get_num_objects() == 3 );
         CHECK( pTuplet->get_id() == 137L );
 
         ++it;
@@ -2135,7 +2135,7 @@
         CHECK( pTuplet->get_actual_number() == 1 );
         CHECK( pTuplet->get_normal_number() == 1 );
         CHECK( pTuplet->get_show_bracket() == k_yesno_yes );
-        CHECK( pTuplet->get_num_objects() == 2 );
+        CHECK( pTuplet->get_num_objects() == 3 );
         CHECK( pTuplet->get_id() == 141L );
 
         a.do_not_delete_instruments_in_destructor();
@@ -2198,7 +2198,7 @@
         CHECK( pTuplet->get_actual_number() == 3 );
         CHECK( pTuplet->get_normal_number() == 2 );
         CHECK( pTuplet->get_show_bracket() == k_yesno_yes );
-        CHECK( pTuplet->get_num_objects() == 2 );
+        CHECK( pTuplet->get_num_objects() == 3 );
         CHECK( pTuplet->get_id() == 141L );
 
         a.do_not_delete_instruments_in_destructor();

=== modified file 'test-scores/01014-nested-tuplets.lms'
--- test-scores/01014-nested-tuplets.lms	2016-09-10 14:58:32 +0000
+++ test-scores/01014-nested-tuplets.lms	2016-09-13 14:57:54 +0000
@@ -12,7 +12,7 @@
         (time 2 4)
         (n b4 e (tm 2 3)(beam 1 +)(t 1 + 3 2))
         (n b4 e (tm 2 3)(beam 1 -))
-        (n b4 e (tm 4 15)(beam 2 +)(t 2 + 5 2))
+        (n b4 e (tm 4 15)(beam 2 +)(t 2 + 5 2 (displayBracket yes)))
         (n b4 e (tm 4 15)(beam 2 =))
         (n b4 e (tm 4 15)(beam 2 =))
         (n b4 e (tm 4 15)(beam 2 =))

=== added file 'test-scores/01015-tuplet-braket-position.lms'
--- test-scores/01015-tuplet-braket-position.lms	1970-01-01 00:00:00 +0000
+++ test-scores/01015-tuplet-braket-position.lms	2016-09-13 14:57:54 +0000
@@ -0,0 +1,12 @@
+(score
+   (vers 2.0)
+   (instrument  
+      (musicData 
+         (clef G)
+         (time 2 4)
+         (n f5 e (tm 2 3)(t 1 + 3 2))
+         (n a4 e (stem down)(tm 2 3))
+         (n f5 e (tm 2 3)(t 1 -))
+      )
+   )
+)

